package com.xunmei.system.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.xunmei.common.core.web.page.TableDataInfo;
import com.xunmei.system.api.domain.SysDevice;

/**
 * 【设备管理】Service接口
 *
 * @author xunmei
 * @date 2023-08-22
 */
public interface ISysDeviceService extends IService<SysDevice> {
    /**
     * 查询【设备管理】
     *
     * @param id 【设备管理】主键
     * @return 【设备管理】
     */
    SysDevice selectSysDeviceById(Long id);

    /**
     *
     * @param orgId
     * @return
     */
    List<SysDevice> getHostByOrgId(Long orgId);

    /**
     * 查询【设备管理】列表
     *
     * @param sysDevice 【设备管理】
     * @return 【设备管理】集合
     */
    List<SysDevice> selectSysDeviceList(SysDevice sysDevice);
List<SysDevice> getSysDeviceByHostId(Long hostId);
    /**
     * 新增【设备管理】
     *
     * @param sysDevice 【设备管理】
     * @return 结果
     */
    int insertSysDevice(SysDevice sysDevice);

    /**
     * 修改【设备管理】
     *
     * @param sysDevice 【设备管理】
     * @return 结果
     */
    int updateSysDevice(SysDevice sysDevice);

    /**
     * 批量删除【设备管理】
     *
     * @param ids 需要删除的【设备管理】主键集合
     * @return 结果
     */
    int deleteSysDeviceByIds(Long[] ids);

    /**
     * 删除【设备管理】信息
     *
     * @param id 【设备管理】主键
     * @return 结果
     */
    int deleteSysDeviceById(Long id);

    /**
     * 查询【设备管理】分页数据
     *
     * @param sysDevice 查询条件对象
     * @return Page
     */
    TableDataInfo<SysDevice> selectPage(SysDevice sysDevice);
}
