package com.xunmei.system.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.xunmei.system.api.domain.SysDevice;
import org.apache.ibatis.annotations.Mapper;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author xunmei
 * @date 2023-08-22
 */
@Mapper
public interface SysDeviceMapper extends BaseMapper<SysDevice> {
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
     SysDevice selectSysDeviceById(Long id);

    /**
     * 根据机构查出所有的视频主机
     * @param orgId
     * @return
     */
     List<SysDevice> getHostByOrgId(Long orgId);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param sysDevice 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
     List<SysDevice> selectSysDeviceList(SysDevice sysDevice);

    /**
     * 新增【请填写功能名称】
     *
     * @param sysDevice 【请填写功能名称】
     * @return 结果
     */
     int insertSysDevice(SysDevice sysDevice);

    /**
     * 修改【请填写功能名称】
     *
     * @param sysDevice 【请填写功能名称】
     * @return 结果
     */
     int updateSysDevice(SysDevice sysDevice);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
     int deleteSysDeviceById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteSysDeviceByIds(Long[] ids);
}
